@@ -67,7 +67,7 @@ def obj_to_bytes(obj):
         obj = obj.encode()
     elif not isinstance(obj, bytes):
         try:
-            obj = json.dumps(obj, indent=2)
+            obj = str2html(json.dumps(obj, indent=2))
         except:
             obj = str(obj)
         obj = obj.encode()
